/*
  tdump - Trivial hex dump - all output on 1 line!
  
  This file is part of the Linux lsvpd package.
  
  (C) Copyright IBM Corp. 2002, 2003, 2004
  
  Maintained by  Martin Schwenke <martins@au.ibm.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  $Id: tdump.c,v 1.10 2004/09/22 04:55:38 martins Exp $
*/
  
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include <unistd.h>

#include "util.h"

char *optarg;
extern int optind, opterr, optopt;

static void
usage()
{
	fprintf(stderr,
		"usage: %s [-c] [ -s string | file ]\n",
		vpd_program_name);
	exit(1);
}

int
main(int argc, char ** argv)
{
	char * data = NULL;
	size_t len;
	int    err;

	int opt;
	bool compact = false;

	char * file = NULL;

	int ret = 0;

	vpd_program_name = argv[0];

	while ((opt = getopt(argc, argv, "cs:")) != -1) {
		switch (opt) {
		case 'c':
			compact = true;
			break;
		case 's':
			if (optarg) {
				len = strlen(optarg);
				data = malloc(len);
				strcpy(data, optarg);
			} else {
				usage();
			}
			break;
		default:
			usage();
			break;
		}
	}

	if ((optind + 1) < argc)
		usage();

	if ((optind + 1) == argc) {
		if (data == NULL)
			file = argv[optind];
		else
			usage();
	}

	if ((data != NULL) ||
	    file_read_contents(file, &data, &len, &err)) {
		bool first = true;
		int i;
		for (i = 0; i < len; i++) {
			if (!first && !compact)
				printf(" ");
			printf("%.2x", (unsigned char) data[i]);
			first = false;
		}
		printf("\n");
		free(data);
	} else {
		die2(strerror(err), file == NULL ? "<STDIN>" : file);
	}

	return ret;
}
