/*
  test_vpd - Test code for in memory and disk-based VPD utilities.
  
  This file is part of the Linux lsvpd package.
  
  (C) Copyright IBM Corp. 2004
  
  Maintained by  Martin Schwenke <martins@au.ibm.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  $Id: test_vpd.c,v 1.2 2004/12/20 10:26:56 martins Exp $
*/
  
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#include "vpd.h"
#include "growbuf.h"
#include "util.h"

int
main(int argc, char ** argv)
{
	growbuf * intext;
	growbuf * outtext;
	growbuf * t;
	vpd_list * vl;
	vpd_list_list * vll;

	FILE * f;

	char * data;
	size_t len;
	int err;

	vpd_program_name = argv[0];

	if (argc != 5) {
		fprintf(stderr, "vpd intext outtext1 outtext2 dir\n");
		return 1;
	}

	if (!file_read_contents(argv[1], &data, &len, &err)) {
		die2(strerror(err), argv[1]);
	}

	intext = growbuf_append(growbuf_new(len), data, len);
	free(data);

	if (NULL == (f = fopen(argv[2], "w"))) {
		die2(strerror(err), argv[2]);
	}

	if (NULL == (vl = vpd_text_to_vpd_list(intext))) {
		die("vpd_text_to_vpd_list failed");
	}

	outtext = growbuf_new(len);
	if (!vpd_list_to_text(vl, &outtext))
		die("vpd_list_to_text failed");

	fwrite(growbuf_data(outtext), growbuf_length(outtext), 1, f);
	vpd_list_free(vl);
	growbuf_free(outtext);
	fclose(f);

	vll = vpd_text_to_vpd_list_list(intext, "FC");
	growbuf_free(intext);

	if (NULL == vll)
		die("vpd_text_to_vpd_list_list failed");

	t = vpd_list_list_to_text(vll);
	if (NULL == t)
		die("vpd_list_list_to_text failed\n");

	if (NULL == (f = fopen(argv[3], "w"))) {
		die2(strerror(err), argv[3]);
	}
	fwrite(growbuf_data(t), growbuf_length(t), 1, f);
	fclose(f);
	growbuf_free(t);
	
	if (!vpd_list_list_to_node(vll, argv[4]))
		die("vpd_list_list_to_node failed\n");
	
	vpd_list_list_free(vll);
		
	return 0;
}
