#ifndef _VPD_H_
#define _VPD_H_

/*
  vpd - Utilities for in memory and disk-based VPD handling.
  
  This file is part of the Linux lsvpd package.
  
  (C) Copyright IBM Corp. 2002, 2003, 2004, 2005
  
  Maintained by  Martin Schwenke <martins@au.ibm.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  $Id: vpd.h,v 1.5 2005/02/22 22:30:10 martins Exp $
*/
  
#include <stdbool.h>
#include <sys/types.h>

#include "list.h"
#include "growbuf.h"

typedef char vpd_key[2];

typedef struct vpd_list {
	vpd_key          key;
	char *           val;
	struct list_head head;
} vpd_list;

typedef struct vpd_list_list {
	vpd_list *        vpd_list;
	struct list_head  head;
} vpd_list_list;


extern vpd_list *
vpd_list_new_empty();

extern vpd_list *
vpd_list_new(const vpd_key k,
	     const char * v,
	     size_t vlen);

extern void
vpd_list_free(vpd_list * vl);

extern vpd_list_list *
vpd_list_list_new_empty();

extern vpd_list_list *
vpd_list_list_new(vpd_list * vl);

extern void
vpd_list_list_free(vpd_list_list * vll);

extern vpd_list *
vpd_list_append(vpd_list * vl,
		vpd_list * new);

extern vpd_list *
vpd_list_prepend(vpd_list * vl,
		 vpd_list * new);

extern vpd_list *
vpd_list_append_key_value(vpd_list * vl,
			  const vpd_key k,
			  const char * v, size_t vlen);

extern vpd_list *
vpd_list_prepend_key_value(vpd_list * vl,
			   const vpd_key k,
			   const char * v, size_t vlen);

extern vpd_list_list *
vpd_list_list_append(vpd_list_list * vll,
		     vpd_list * vl);

extern bool
vpd_list_to_text(const vpd_list * vl,
		 growbuf ** buf);

extern growbuf *
vpd_list_list_to_text(const vpd_list_list * vll);

extern bool
vpd_list_to_vpd_dir(const vpd_list * vl,
		    const char * vpd_dir);

extern bool
vpd_list_list_to_node(const vpd_list_list * vll,
		      const char * node);

extern vpd_list *
vpd_text_to_vpd_list(const growbuf * buf);

extern vpd_list_list *
vpd_text_to_vpd_list_list(const growbuf * buf,
			  const vpd_key sep);

extern char *
vpd_dir_get_subdirnum(const char * dir,
		      int subdirnum);

extern char *
vpd_dir_get_default(const char * dir);

extern bool
vpd_dir_field_ensure(const char * vpd_dir,
		     const vpd_key field,
		     const char * value);

#endif
