#ifndef PCI_ETHERNET_H
#define PCI_ETHERNET_H

/*
  pci_ethernet - Get PCI (and other) information for ethernet adapters.
  
  This file is part of the Linux lsvpd package.
  
  (C) Copyright IBM Corp. 2004
  
  Maintained by  Martin Schwenke <martins@au.ibm.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  $Id: pci_ethernet.h,v 1.4 2004/10/15 05:27:27 martins Exp $
*/
  
#include <sys/types.h>

#include "util.h"

#define PCI_ETHERNET_HWADDR_LEN 6

typedef struct pci_ethernet {
	char *                name;
	uint32_t              dom;
	uint8_t               bus;
	uint8_t               dev;
	uint8_t               fun;
	uint16_t              irq;
	uint64_t              mem_start;
	uint64_t              mem_end;
	char                  fw_version[32];
	unsigned char         hwaddr[PCI_ETHERNET_HWADDR_LEN];
	struct pci_ethernet * next;
} pci_ethernet_t;

#define PCI_ETHERNET_NODOM 0xffffffff

extern pci_ethernet_t *
pci_ethernet();

extern void
pci_ethernet_free(pci_ethernet_t * l);

extern void
pci_ethernet_fprint(FILE * f, pci_ethernet_t * ep);

#endif
